@@ -1,8 +1,9 @@
 use strict;
 use warnings;
 package HTML::Widget::Plugin::JS;
+$HTML::Widget::Plugin::JS::VERSION = '0.006';
 # ABSTRACT: a JavaScript variable declaration emitter
-$HTML::Widget::Plugin::JS::VERSION = '0.005';
+
 use parent qw(HTML::Widget::Plugin);
 
 use Data::JavaScript::Anon;
@@ -38,7 +39,7 @@ sub js_vars {
 
   my $str =
     join "\n",
-    map  { Data::JavaScript::Anon->var_dump($_ => $arg->{$_}) }
+    map  { HTML::Widget::Plugin::JS::Encoder->var_dump($_ => $arg->{$_}) }
     keys %$arg;
 
   return $str;
@@ -52,12 +53,31 @@ BEGIN { *js_var = \&js_vars }
 #pod structure.  This basically just provides a widget factory interface to
 #pod Data::JavaScript::Anon.
 #pod
+#pod It also escapes end-tag-like content in strings, using a JavaScript C<\u003c>
+#pod form to avoid being interpreted as a real end tag in JavaScript embedded in
+#pod HTML.
+#pod
+#pod Software is terrible.
+#pod
 #pod =cut
 
 sub js_anon {
   my ($self, $factory, $arg) = @_;
 
-  Data::JavaScript::Anon->anon_dump($arg);
+  HTML::Widget::Plugin::JS::Encoder->anon_dump($arg);
+}
+
+{
+  package
+    HTML::Widget::Plugin::JS::Encoder;
+  use parent 'Data::JavaScript::Anon';
+
+  sub _escape {
+    my ($self, $text) = @_;
+    $text = $self->SUPER::_escape($text);
+    $text =~ s/</\\u003c/g;
+    return $text;
+  }
 }
 
 1;
@@ -74,7 +94,7 @@ HTML::Widget::Plugin::JS - a JavaScript variable declaration emitter
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head2 js_var
 
@@ -101,10 +121,22 @@ This widget converts a given data structure to an anonymous JavaScript
 structure.  This basically just provides a widget factory interface to
 Data::JavaScript::Anon.
 
+It also escapes end-tag-like content in strings, using a JavaScript C<\u003c>
+form to avoid being interpreted as a real end tag in JavaScript embedded in
+HTML.
+
+Software is terrible.
+
 =head1 AUTHOR
 
 Ricardo SIGNES
 
+=head1 CONTRIBUTOR
+
+=for stopwords Ricardo SIGNES
+
+Ricardo SIGNES <rjbs@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2008 by Ricardo SIGNES.
